@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "ea444c35bb23b6e34505ab6753e069de7801cc25"
-#define GIT_BRANCH         "v0.53.0"
-#define GIT_COMMIT_MESSAGE "version: bump to 0.53.0"
-#define GIT_COMMIT_DATE    "Mon Dec 29 15:21:36 2025"
+#define GIT_COMMIT_HASH    "ab1d80f3d6aebd57a0971b53a1993b1c1dfe0b09"
+#define GIT_BRANCH         "v0.53.1"
+#define GIT_COMMIT_MESSAGE "version: bump to 0.53.1"
+#define GIT_COMMIT_DATE    "Fri Jan 2 21:20:57 2026"
 #define GIT_DIRTY          "clean"
-#define GIT_TAG            "v0.53.0"
-#define GIT_COMMITS        "6756"
+#define GIT_TAG            "v0.53.1"
+#define GIT_COMMITS        "6766"
 
 #define AQUAMARINE_VERSION "0.10.0"
 // clang-format off
